pub fn wrap_tx_input(
input: &mut TxIn,
signer_pk: &XOnlyPublicKey,
) -> Result<Option<ScriptBuf>>Expand description
Changes the script to the wrapped script and modifies the control block accordingly Returns the newly created wrapped script